Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(48)

Unified Diff: content/browser/browser_main_loop.h

Issue 1315463002: [Startup Tracing] Add --trace-config-file flag (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: review fix - blundell Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/browser_main_loop.h
diff --git a/content/browser/browser_main_loop.h b/content/browser/browser_main_loop.h
index 5f87e69191bf4af7ca50dc799482dc8aa00ebacc..822589e702db6f1c28ff515eb65a7dfa612f8051 100644
--- a/content/browser/browser_main_loop.h
+++ b/content/browser/browser_main_loop.h
@@ -116,7 +116,9 @@ class CONTENT_EXPORT BrowserMainLoop {
media::midi::MidiManager* midi_manager() const { return midi_manager_.get(); }
base::Thread* indexed_db_thread() const { return indexed_db_thread_.get(); }
- bool is_tracing_startup() const { return is_tracing_startup_; }
+ bool is_tracing_startup_for_duration() const {
+ return is_tracing_startup_for_duration_;
+ }
const base::FilePath& startup_trace_file() const {
return startup_trace_file_;
@@ -152,7 +154,7 @@ class CONTENT_EXPORT BrowserMainLoop {
base::FilePath GetStartupTraceFileName(
const base::CommandLine& command_line) const;
- void InitStartupTracing(const base::CommandLine& command_line);
+ void InitStartupTracingForDuration(const base::CommandLine& command_line);
void EndStartupTracing();
bool UsingInProcessGpu() const;
@@ -166,7 +168,7 @@ class CONTENT_EXPORT BrowserMainLoop {
// MainMessageLoopStart()
// InitializeMainThread()
// PostMainMessageLoopStart()
- // InitStartupTracing()
+ // InitStartupTracingForDuration()
// CreateStartupTasks()
// PreCreateThreads()
// CreateThreads()
@@ -177,7 +179,7 @@ class CONTENT_EXPORT BrowserMainLoop {
const base::CommandLine& parsed_command_line_;
int result_code_;
bool created_threads_; // True if the non-UI threads were created.
- bool is_tracing_startup_;
+ bool is_tracing_startup_for_duration_;
// Members initialized in |MainMessageLoopStart()| ---------------------------
scoped_ptr<base::MessageLoop> main_message_loop_;
@@ -206,7 +208,7 @@ class CONTENT_EXPORT BrowserMainLoop {
scoped_ptr<MemoryObserver> memory_observer_;
scoped_ptr<base::trace_event::TraceMemoryController> trace_memory_controller_;
// Members initialized in |InitStartupTracing()| -----------------------------
base::FilePath startup_trace_file_;
// This timer initiates trace file saving.
@@ -206,7 +208,7 @@ class CONTENT_EXPORT BrowserMainLoop {
scoped_ptr<MemoryObserver> memory_observer_;
scoped_ptr<base::trace_event::TraceMemoryController> trace_memory_controller_;
- // Members initialized in |InitStartupTracing()| -----------------------------
+ // Members initialized in |InitStartupTracingForDuration()| ------------------
base::FilePath startup_trace_file_;
// This timer initiates trace file saving.

Powered by Google App Engine
This is Rietveld 408576698